@@ -1,9 +1,9 @@
 import urllib.parse
 
 import httpx
-from pydantic import parse_obj_as
 
 from what_to_eat.models.location import Location
+from what_to_eat.utils import cache
 
 
 class LocationError(Exception):
@@ -11,7 +11,8 @@ class LocationError(Exception):
         super().__init__("Error when trying to get location")
 
 
-def _get(address: str) -> Location:
+@cache.apply()
+def get(address: str) -> Location:
     address = urllib.parse.quote(address)
     response = httpx.get(f"https://nominatim.openstreetmap.org/search/{address}?format=json")
 
@@ -19,7 +20,3 @@ def _get(address: str) -> Location:
         raise LocationError()
 
     return Location.parse_obj(response.json()[0])
-
-
-def get(address: str) -> Location:
-    return parse_obj_as(Location, _get(address))
